<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Lecture;
use App\Models\Enrollment;
use Illuminate\Support\Facades\Auth;

class EnrollmentController extends Controller
{
    /**
     * Enroll in a specific lecture.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $lectureId
     * @return \Illuminate\Http\RedirectResponse
     */
    public function enrollInLecture($lectureId)
    {
        $lecture = Lecture::with('course', 'teacher')->findOrFail($lectureId);  // تأكد من جلب المعلم
    
        // تحقق من إذا كان الطالب مسجلاً بالفعل في المحاضرة
        $existingEnrollment = Enrollment::where('student_id', Auth::user()->student->id)
            ->where('lecture_id', $lecture->id)
            ->first();
    
        if ($existingEnrollment) {
            return redirect()->back()->with('error', 'You are already enrolled in this lecture.');
        }
    
        if (Auth::user()->role != 'student') {
            return redirect()->back()->with('error', 'You must have a student account.');
        }
    
        // إنشاء التسجيل
        Enrollment::create([
            'student_id' => Auth::user()->student->id,
            'lecture_id' => $lecture->id,
            'enrollment_date' => now(),
        ]);
    
        // إضافة سعر الحصة إلى رصيد المعلم
        $teacher = $lecture->teacher;  // جلب المعلم المرتبط بالحصة
        if ($teacher) {
            $teacher->balance += $lecture->price;  // إضافة السعر إلى الرصيد
            $teacher->save();  // حفظ التحديثات
        }
    
        return redirect()->back()->with('success', 'Enrolled in the lecture successfully.');
    }
    

    /**
     * Unenroll from a specific lecture.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $lectureId
     * @return \Illuminate\Http\RedirectResponse
     */
    public function unenrollFromLecture(Request $request, $lectureId)
    {
        $enrollment = Enrollment::where('student_id', Auth::user()->id)
            ->where('lecture_id', $lectureId)
            ->first();

        if (!$enrollment) {
            return redirect()->back()->with('error', 'You are not enrolled in this lecture.');
        }

        $enrollment->delete();

        return redirect()->back()->with('success', 'Unenrolled from the lecture successfully.');
    }
}
